Module beamlit.models.account_spec
==================================

Classes
-------

`AccountSpec(address: beamlit.types.Unset | ForwardRef('AccountSpecAddress') = <beamlit.types.Unset object>, admins: beamlit.types.Unset | list[typing.Any] = <beamlit.types.Unset object>, currency: beamlit.types.Unset | str = <beamlit.types.Unset object>, owner: beamlit.types.Unset | str = <beamlit.types.Unset object>, status: beamlit.types.Unset | str = <beamlit.types.Unset object>, tax_id: beamlit.types.Unset | str = <beamlit.types.Unset object>)`
:   AccountSpec
    
    Attributes:
        address (Union[Unset, AccountSpecAddress]): Billing address
        admins (Union[Unset, list[Any]]): Admins
        currency (Union[Unset, str]): Currency
        owner (Union[Unset, str]): Owner
        status (Union[Unset, str]): Status
        tax_id (Union[Unset, str]): Tax ID
    
    Method generated by attrs for class AccountSpec.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `address`
    :

    `admins`
    :

    `currency`
    :

    `owner`
    :

    `status`
    :

    `tax_id`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :